@@ -105,7 +105,7 @@ class RethinkDBClient(BaseStorageClient):
         ).table(
             object_type
         ).get_all(
-            *value if isinstance(value, list) else value,
+            *value if isinstance(value, list) else [value],
             index=index
         ).run(self._connection)
 
