@@ -132,3 +132,19 @@ class RethinkDBClientTest(IsolatedAsyncioTestCase):
 
         self.assertEqual(len(await self.TestModel.find({'test_str': 'Test4'})), 3)
         self.assertEqual(len(await self.TestModel.find({'test_str': 'Test44'})), 2)
+
+    async def test_find_models(self):
+        await Eyja.reset()
+        await Eyja.init(
+            config=self.config,
+            plugins=['eyja_rethinkdb']
+        )
+
+        await self.TestModel(test_str='Test5').save()
+        await self.TestModel(test_str='Test5').save()
+        await self.TestModel(test_str='Test5').save()
+        await self.TestModel(test_str='Test55').save()
+        await self.TestModel(test_str='Test55').save()
+
+        self.assertEqual(await self.TestModel.count({'test_str': 'Test5'}), 3)
+        self.assertEqual(await self.TestModel.count({'test_str': 'Test55'}), 2)
